@@ -1,11 +1,12 @@
 from __future__ import annotations
 
+from collections import namedtuple
 from typing import Sequence
 
 import ndindex
 import numpy as np
 
-from blosc2 import blosc2_ext, compute_chunks_blocks
+from blosc2 import SpecialValue, blosc2_ext, compute_chunks_blocks
 
 from .info import InfoReporter
 from .schunk import SChunk
@@ -114,11 +115,15 @@ class NDArray(blosc2_ext.NDArray):
                [3.3333, 3.3333, 3.3333, 3.3333, 3.3333],
                [3.3333, 3.3333, 3.3333, 3.3333, 3.3333]])
         """
-        key, _ = process_key(key, self.shape)
+        key, mask = process_key(key, self.shape)
         start, stop, _ = get_ndarray_start_stop(self.ndim, key, self.shape)
         key = (start, stop)
-        shape = [sp - st for st, sp in zip(start, stop)]
-        arr = np.zeros(shape, dtype=self.dtype)
+        shape = np.array([sp - st for st, sp in zip(start, stop)])
+        shape = tuple(shape[[not m for m in mask]])
+        # arr = np.zeros(shape, dtype=self.dtype)
+        # Benchmarking shows that empty is faster than zeros
+        # (besides we don't need to fill padding with zeros)
+        arr = np.empty(shape, dtype=self.dtype)
 
         return super(NDArray, self).get_slice_numpy(arr, key)
 
@@ -165,6 +170,32 @@ class NDArray(blosc2_ext.NDArray):
 
         return super(NDArray, self).set_slice(key, value)
 
+    def iterchunks_info(self):
+        """
+        Iterate over :paramref:`self` chunks, providing info on index and special values.
+
+        Yields
+        ------
+        info: namedtuple
+            A namedtuple with the following fields:
+            nchunk: the index of the chunk (int).
+            coords: the coordinates of the chunk, in chunk units (tuple).
+            cratio: the compression ratio of the chunk (float).
+            special: the special value enum of the chunk; if 0, the chunk is not special (SpecialValue).
+            repeated_value: the repeated value for the chunk; if not SpecialValue.VALUE, it is None.
+            lazychunk: a buffer with the complete lazy chunk (bytes).
+        """
+        ChunkInfoNDArray = namedtuple(
+            "ChunkInfoNDArray", ["nchunk", "coords", "cratio", "special", "repeated_value", "lazychunk"]
+        )
+        chunks_idx = np.array(self.ext_shape) // np.array(self.chunks)
+        for cinfo in self.schunk.iterchunks_info():
+            nchunk, cratio, special, repeated_value, lazychunk = cinfo
+            coords = tuple(np.unravel_index(cinfo.nchunk, chunks_idx))
+            if cinfo.special == SpecialValue.VALUE:
+                repeated_value = np.frombuffer(cinfo.repeated_value, dtype=self.dtype)[0]
+            yield ChunkInfoNDArray(nchunk, coords, cratio, special, repeated_value, lazychunk)
+
     def tobytes(self):
         """Returns a buffer with the data contents.
 
